@@ -1,4 +1,4 @@
-#!/usr/bin/python -tt
+#!@PYTHON@ -tt
 
 #####
 ##
@@ -14,7 +14,7 @@
 ##        cipher (des/blowfish) have to be defined
 #####
 
-import sys, re
+import sys, re, time
 import atexit
 sys.path.append("@FENCEAGENTSLIBDIR@")
 from fencing import *
@@ -26,6 +26,10 @@ REDHAT_COPYRIGHT=""
 BUILD_DATE="March, 2008"
 #END_VERSION_GENERATION
 
+# Fix for connection timed out issue in:
+# https://bugzilla.redhat.com/show_bug.cgi?id=1342584
+TIMEDOUT_DELAY = 0.5
+
 def get_power_status(conn, options):
 	exp_result = 0
 	outlets = {}
@@ -40,10 +44,10 @@ def get_power_status(conn, options):
 	if None != re.compile('.* MasterSwitch plus.*', re.IGNORECASE | re.S).match(conn.before):
 		switch = 1
 		if None != re.compile('.* MasterSwitch plus 2', re.IGNORECASE | re.S).match(conn.before):
-			if not options.has_key("--switch"):
+			if "--switch" not in options:
 				fail_usage("Failed: You have to enter physical switch number")
 		else:
-			if not options.has_key("--switch"):
+			if "--switch" not in options:
 				options["--switch"] = "1"
 
 	if None == re.compile('.*Outlet Management.*', re.IGNORECASE | re.S).match(conn.before):
@@ -78,10 +82,11 @@ def get_power_status(conn, options):
 			res = show_re.search(line)
 			if res != None:
 				outlets[res.group(2)] = (res.group(3), res.group(4))
+		time.sleep(TIMEDOUT_DELAY)
 		conn.send_eol("")
 		if exp_result != 0:
 			break
-	conn.send(chr(03))
+	conn.send(chr(0o3))
 	conn.log_expect("- Logout", int(options["--shell-timeout"]))
 	conn.log_expect(options["--command-prompt"], int(options["--shell-timeout"]))
 
@@ -116,10 +121,10 @@ def set_power_status(conn, options):
 			'off': "3"
 		}[options["--action"]]
 		if None != re.compile('.* MasterSwitch plus 2', re.IGNORECASE | re.S).match(conn.before):
-			if not options.has_key("--switch"):
+			if "--switch" not in options:
 				fail_usage("Failed: You have to enter physical switch number")
 		else:
-			if not options.has_key("--switch"):
+			if "--switch" not in options:
 				options["--switch"] = 1
 
 	if None == re.compile('.*Outlet Management.*', re.IGNORECASE | re.S).match(conn.before):
@@ -151,6 +156,7 @@ def set_power_status(conn, options):
 
 	while 0 == conn.log_expect(
 			["Press <ENTER>"] + options["--command-prompt"], int(options["--shell-timeout"])):
+		time.sleep(TIMEDOUT_DELAY)
 		conn.send_eol("")
 
 	conn.send_eol(options["--plug"]+"")
@@ -171,9 +177,10 @@ def set_power_status(conn, options):
 	conn.log_expect("Enter 'YES' to continue or <ENTER> to cancel :", int(options["--shell-timeout"]))
 	conn.send_eol("YES")
 	conn.log_expect("Press <ENTER> to continue...", int(options["--power-timeout"]))
+	time.sleep(TIMEDOUT_DELAY)
 	conn.send_eol("")
 	conn.log_expect(options["--command-prompt"], int(options["--power-timeout"]))
-	conn.send(chr(03))
+	conn.send(chr(0o3))
 	conn.log_expect("- Logout", int(options["--shell-timeout"]))
 	conn.log_expect(options["--command-prompt"], int(options["--shell-timeout"]))
 
@@ -232,7 +239,7 @@ will block any necessary fencing actions."
 	show_docs(options, docs)
 
 	## Support for --plug [switch]:[plug] notation that was used before
-	if (options.has_key("--plug") == 1) and (-1 != options["--plug"].find(":")):
+	if (("--plug" in options) == 1) and (-1 != options["--plug"].find(":")):
 		(switch, plug) = options["--plug"].split(":", 1)
 		options["--switch"] = switch
 		options["--plug"] = plug
