@@ -1,4 +1,4 @@
-#!/usr/bin/python -tt
+#!@PYTHON@ -tt
 
 import sys, re, os
 import atexit
@@ -35,7 +35,7 @@ def create_command(options, action):
 	cmd = options["--ipmitool-path"]
 
 	# --lanplus / -L
-	if options.has_key("--lanplus") and options["--lanplus"] in ["", "1"]:
+	if "--lanplus" in options and options["--lanplus"] in ["", "1"]:
 		cmd += " -I lanplus"
 	else:
 		cmd += " -I lan"
@@ -43,15 +43,15 @@ def create_command(options, action):
 	cmd += " -H " + options["--ip"]
 
 	# --username / -l
-	if options.has_key("--username") and len(options["--username"]) != 0:
+	if "--username" in options and len(options["--username"]) != 0:
 		cmd += " -U " + quote(options["--username"])
 
 	# --auth / -A
-	if options.has_key("--auth"):
+	if "--auth" in options:
 		cmd += " -A " + options["--auth"]
 
 	# --password / -p
-	if options.has_key("--password"):
+	if "--password" in options:
 		cmd += " -P " + quote(options["--password"])
 	else:
 		cmd += " -P ''"
@@ -61,17 +61,17 @@ def create_command(options, action):
 		cmd += " -C " + options["--cipher"]
 
 	# --port / -n
-	if options.has_key("--ipport"):
+	if "--ipport" in options:
 		cmd += " -p " + options["--ipport"]
 
-	if options.has_key("--privlvl"):
+	if "--privlvl" in options:
 		cmd += " -L " + options["--privlvl"]
 
 	# --action / -o
 	cmd += " chassis power " + action
 
 	# --use-sudo / -d
-	if options.has_key("--use-sudo"):
+	if "--use-sudo" in options:
 		cmd = options["--sudo-path"] + " " + cmd
 
 	return cmd
@@ -140,6 +140,9 @@ def main():
 		all_opt["lanplus"]["default"] = "1"
 
 	all_opt["ipport"]["default"] = "623"
+	all_opt["method"]["help"] = "-m, --method=[method]          Method to fence (onoff|cycle) (Default: cycle)\n" \
+				    "WARNING! This fence agent might report success before the node is powered off. " \
+				    "You should use -m/method onoff if your fence device works correctly with that option."
 
 	options = check_input(device_opt, process_input(device_opt))
 
@@ -147,7 +150,9 @@ def main():
 	docs["shortdesc"] = "Fence agent for IPMI"
 	docs["longdesc"] = "fence_ipmilan is an I/O Fencing agent\
 which can be used with machines controlled by IPMI.\
-This agent calls support software ipmitool (http://ipmitool.sf.net/)."
+This agent calls support software ipmitool (http://ipmitool.sf.net/). \
+WARNING! This fence agent might report success before the node is powered off. \
+You should use -m/method onoff if your fence device works correctly with that option."
 	docs["vendorurl"] = ""
 	docs["symlink"] = [("fence_ilo3", "Fence agent for HP iLO3"),
 		("fence_ilo4", "Fence agent for HP iLO4"),
